function y = analytic_solution(x, m, g, n, L, gamma)
    % Analytic solution to Hanging Catenary problem
    % Use to compare to optimisation-based solution
    % Do not try to derive this expression in class
    % Lindon Roberts, 2019
    
    % Find relevant solution constants
    rho = m/L; % density per unit length of beam
    c = (m*g*(n+1)./(2.*L))*fsolve(@(ctilde)ctilde.*sinh(gamma./ctilde) - L, 1, optimoptions('fsolve', 'Display', 'off'));
    lambda = c*cosh(m*g*gamma*(n+1)./(2*c));
    xmid = gamma*(n+1)*L/2;
    
    % Analytic solution
    y = (c./(rho*g)) .* cosh(rho*g*(x-xmid)/c) - lambda/(rho*g);
end
