function varargout = objfun(x, m, g)
    % Hanging Catenary objective function
    % Lindon Roberts, 2019
    
    % Call as:
    %   f      = objfun(x, m, g);  % function value only
    %   [f, g] = objfun(x, m, g);  % function value and gradient
    
    if nargout > 2
        error('Invalid number of output arguments');
    end
    
    % x is large vector of size 3*(n+2)
    n = (numel(x)-6)/3;
    
    % The first n+2 elements are the x-coordinates
    % The next n+2 elements are the y-coordinates
    % The last n+2 elements are the z-coordinates
    xcoords = x(1:n+2);
    ycoords = x(n+3:2*n+4);
    zcoords = x(2*n+5:end);
    
    % Objective function
    f = m*g*(0.5*ycoords(1) + sum(ycoords(2:end-1)) + 0.5*ycoords(end));
    varargout{1} = f;
    
    if nargout > 1
        % Gradient
        grad = zeros(3*(n+2),1);
        grad(n+3) = 0.5*m*g;
        grad(n+4:2*n+3) = m*g;
        grad(2*n+4) = 0.5*m*g;
        varargout{2} = grad;
    end
end
